SharedReadLock

Struct SharedReadLock 

pub struct SharedReadLock<'a, T: ?Sized> { /* private fields */ }
This holds a read lock on the underlying container’s object.

The particular behaviour of the lock depends on the underlying synchronization primitive.