Struct SharedReadLock
Source pub struct SharedReadLock<'a, T: ?Sized> { }
This holds a read lock on the underlying container’s object.
The particular behaviour of the lock depends on the underlying synchronization primitive.
SourceImplement AsMut where T: AsMut
Converts this type into a mutable reference of the (usually inferred) input type.
SourceImplement AsRef where T: AsRef
Converts this type into a shared reference of the (usually inferred) input type.
Immutably borrows from an owned value.
Read moreSourceImplement Debug where T: Debug.
Formats the value using the given formatter.
Read more
The resulting type after dereferencing.
Dereferences the value.
SourceImplement Display where T: Display.
Formats the value using the given formatter.
Read more
Executes the destructor for this type.
Read moreSourceImplement Error where T: Error
👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
👎Deprecated since 1.42.0: use the Display impl or to_string()
Returns the lower-level source of this error, if any.
Read more
🔬This is a nightly-only experimental API. (error_generic_member_access)
Provides type-based access to context intended for error reports.
Read moreSourceImplement PartialEq, but only for raw types.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
SourceImplement PartialOrd, but only for raw types.
This method returns an ordering between
self and
other values if one exists.
Read more
Tests less than (for
self and
other) and is used by the
< operator.
Read more
Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more
Tests greater than (for
self and
other) and is used by the
>
operator.
Read more
Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
🔬This is a nightly-only experimental API. (arbitrary_self_types)
The target type on which the method may be called.
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.